import React, { useState, useEffect, cloneElement } from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var createContext = function createContext() {
  var Context = React.createContext(undefined);

  var useContext = function useContext() {
    var value = React.useContext(Context);
    if (value === undefined) throw new Error('useContext must be used within a Provider with a value');
    return value;
  };

  return [useContext, Context.Provider];
};

var isClient = typeof window === 'object';
var useLocalStorage = function useLocalStorage(key, initialValue) {
  var _useState = useState(function () {
    if (!isClient) {
      return undefined;
    }

    try {
      var localStorageValue = window.localStorage.getItem(key);
      return localStorageValue === null ? initialValue : JSON.parse(localStorageValue);
    } catch (error) {
      console.error(error);
      return initialValue;
    }
  }),
      storedValue = _useState[0],
      setStoredValue = _useState[1];

  useEffect(function () {
    try {
      window.localStorage.setItem(key, JSON.stringify(storedValue));
    } catch (error) {
      console.error(error);
    }
  }, [storedValue]);
  return [storedValue, setStoredValue];
};

var _createContext = createContext(),
    useOnboard = _createContext[0],
    OnboardContextProvider = _createContext[1];

var useOnboardProvider = function useOnboardProvider(messages, showCallback, ackCallback, HighlightElement) {
  var _useLocalStorage = useLocalStorage("messagesAcked", []),
      messagesAcked = _useLocalStorage[0],
      setMessagesAcked = _useLocalStorage[1];

  var _useState = useState({}),
      allToggles = _useState[0],
      setAllToggles = _useState[1];

  var _useState2 = useState(),
      activeMessage = _useState2[0],
      setActiveMessage = _useState2[1];

  var ackMessage = function ackMessage(id) {
    !messagesAcked.includes(id) && setMessagesAcked([].concat(messagesAcked, [id]));

    if ((activeMessage === null || activeMessage === void 0 ? void 0 : activeMessage.id) === id) {
      var _activeMessage$toggle;

      activeMessage === null || activeMessage === void 0 ? void 0 : (_activeMessage$toggle = activeMessage.toggles) === null || _activeMessage$toggle === void 0 ? void 0 : _activeMessage$toggle.map(function (toggle) {
        toggle(false);
      });
      ackCallback({
        messageId: activeMessage.id
      });
      setActiveMessage(null);
    }
  };

  useEffect(function () {
    var didCancel = false;

    if ((activeMessage === undefined || activeMessage === null) && !didCancel) {
      messages.filter(function (_ref) {
        var id = _ref.id;
        return !messagesAcked.includes(id);
      }).some(function (_ref2) {
        var id = _ref2.id,
            children = _ref2.children,
            elementIds = _ref2.elementIds;
        var toggles = elementIds === null || elementIds === void 0 ? void 0 : elementIds.map(function (elementId) {
          return eval("allToggles." + elementId);
        });

        if (toggles === undefined || toggles === [] || toggles.filter(function (toggle) {
          return toggle === undefined;
        }).length === 0) {
          setActiveMessage({
            id: id,
            toggles: toggles,
            children: children
          });
          return true;
        }

        return false;
      });
    }

    return function () {
      didCancel = true;
    };
  }, [activeMessage, messagesAcked, allToggles]);
  useEffect(function () {
    if (activeMessage !== null && activeMessage !== undefined) {
      var _activeMessage$toggle2;

      showCallback({
        messageId: activeMessage.id,
        children: activeMessage.children,
        onAck: function onAck() {
          return ackMessage(activeMessage.id);
        }
      });
      (_activeMessage$toggle2 = activeMessage.toggles) === null || _activeMessage$toggle2 === void 0 ? void 0 : _activeMessage$toggle2.map(function (toggle) {
        toggle(true);
      });
    }
  }, [activeMessage]);
  return {
    activeMessageId: activeMessage === null || activeMessage === void 0 ? void 0 : activeMessage.id,
    addToggle: function addToggle(elementId, toggle) {
      setAllToggles(function (toggles) {
        var _extends2;

        return _extends({}, toggles, (_extends2 = {}, _extends2[elementId] = toggle, _extends2));
      });
    },
    ackMessage: ackMessage,
    HighlightElement: HighlightElement
  };
};

var OnboardProvider = function OnboardProvider(_ref3) {
  var children = _ref3.children,
      messages = _ref3.messages,
      showCallback = _ref3.showCallback,
      ackCallback = _ref3.ackCallback,
      HighlightElement = _ref3.HighlightElement;
  var value = useOnboardProvider(messages, showCallback, ackCallback, HighlightElement);
  return React.createElement(OnboardContextProvider, {
    value: value
  }, children);
};

var OnboardElement = function OnboardElement(_ref) {
  var id = _ref.id,
      children = _ref.children;

  var _useState = useState(false),
      isActive = _useState[0],
      setIsActive = _useState[1];

  var _useOnboard = useOnboard(),
      addToggle = _useOnboard.addToggle,
      activeMessageId = _useOnboard.activeMessageId,
      ackMessage = _useOnboard.ackMessage,
      HighlightElement = _useOnboard.HighlightElement;

  useEffect(function () {
    addToggle(id, setIsActive);
  }, []);

  var dismiss = function dismiss() {
    if (isActive) {
      ackMessage(activeMessageId);
    }
  };

  var _useState2 = useState(),
      dismissTimeout = _useState2[0],
      setDismissTimeout = _useState2[1];

  var newChildren = cloneElement(children, _extends({
    style: _extends({
      visibility: 'visible'
    }, children.props.style)
  }, children.props));
  return React.createElement(HighlightElement, {
    onClick: function onClick() {
      dismiss();
      window.clearTimeout(dismissTimeout);
      setDismissTimeout(undefined);
    },
    onMouseOver: function onMouseOver() {
      if (dismissTimeout === undefined) setDismissTimeout(window.setTimeout(dismiss, 1000));
    },
    onMouseLeave: function onMouseLeave() {
      window.clearTimeout(dismissTimeout);
      setDismissTimeout(undefined);
    },
    style: {
      visibility: isActive ? 'initial' : 'hidden'
    }
  }, newChildren);
};

export { OnboardElement, OnboardProvider };
//# sourceMappingURL=index.modern.js.map
